
Peter Silva <peter.silva@canada.ca>
  Project Prime mover, Manager & Evangelist. A lot of Documentation, and 
  Review of Docs. Much discussion with Michel. Small bug fixes.
  wrote none of the code in v2, except most (all?) plugins included with package.
  added the 'plugin' model to v2. Main blame for sr3.
  

Cléa Aumont 
  refactoring of FTP processing to fix timezone support.
  porting many plugins from v2 to sr3. Resolved issued with xattr python modules
  several fixes to status... hmm...
  how about issues: #447, #438, #435, #433, #433, #381, #378, #366, #350

Reid Sunderland 
  Added SASL authentication and vhost support.
  Extensive work getting flow tests working with sr3.
  worked on some refactoring as well.

Cody Au 
  fixes #413, #387,  #348. working on sr process management.

Michel Grenier <michel.grenier@IamRetiredNow.ca> (Retired)
  dd_subscribe, sr_subscribe, sr_sarra, sr_post, 
  All of the code until 2016/03. 
  A lot of the code, until 2017/08-2018/05 (major refactoring.)
  Retired now...
  none of the code since sr3, but a lot was copy/pasted.

Jun Hu <jun.hu3@canada.ca>
  Documentation Diagrams, lead on some deployments (head tester!)
  plugin work.

Noureddine Habili <Noureddine.Habili@canada.ca>
  lead on other deployments ( project lead on Sarrasemina )
  plugin work.

Benoit Lapointe <Benoit.Lapointe@canada.ca>
  Improving testing frameworks/ Design documentation / code hygiene.
  Some MQTT interop work. 

Khosrow Ebrahimpour <khosrow@ChangedJobs.ca> (no long involved.)
  Packaging & Process (Debian, Launchpad, some pypi, the vagrant self-test)
  originally proposed migration to github.

Daluma Sen <Daluma.Sen@canada.ca>
  some work on sr_watch, and worked on sr_post as well for caching.

Murray Rennie <Murray.Rennie@canada.ca>
  sr_winnow, worked on that with Michel.
  lots of work on plugins and LDM bridge for UNIDATA and NOAAPORT ingest.

Dominic.Racette <Dominic.Racette@canada.ca>
  actually a client, not really an author, but participation was crucial.
  for five years of patient testing in a very large deployment scenario.


credit for Sarracenia image used as github avatar photo
  Jay Lechtman jay.lechtman@gmail.com - www.horrorculture.weebly.com

